// Do file - gen variables, create figures, perform analysis
// Moral Constraints, Social Norm Enforcement and Strategic Default in Weak and Strong Economic Conditions
// by Brown, Schmitz and Zehnder
// Journal of Money, Credit and Banking

capture log close
set more off
clear all

// set global, data, graphics and tablepath // optional: data can also be imported directly from file 

global project_path "SET GLOBAL PATH HERE" 
//make sure to have the folders "data", "tables" and "graphs" created in the global path folder
global datapath "$project_path\data"
global tablepath "$project_path\tables"
global graphixpath "$project_path\graphs"


import delimited "$datapath\MS23-050_data_for_analysis.csv"
//the dataset contains all experimental data and variables for analysis

save "$datapath\MS23-050_data_for_analysis.dta", replace

clear

// gen stata datasets from .csv files needed to illustrate theory
//note these datasets are manually created to visually display properties of the theoretical predictions and propositions

import delimited "$datapath\MS23-050_no_enforcer_theory_figure.csv"

save "$datapath\MS23-050_no_enforcer_theory_figure", replace

clear

import delimited "$datapath\MS23-050_enforcer_theory_figure.csv"

save "$datapath\MS23-050_enforcer_theory_figure", replace

clear




**********************************
*FIGURES
**********************************
 
//Figure 1: Borrower-level strategic default rates (WE no enforcer vs. SE no enforcer)
  
  clear
use "$datapath\MS23-050_data_for_analysis.dta" 
  
//Left-hand figure: WE no enforcer 


histogram indivd_strat_def_rate if period==20&treatment==1,  bin(10) percent addlabel title(WE no enforcer) ylabel(0(10) 60) xlabel(0(0.1)1) scheme(s2mono) graphregion(fcolor(white)lcolor(white)) xtitle("")

graph export "$graphixpath\MS23-050_Figure1_left.eps", replace

//Right-hand figure: SE no enforcer 

histogram indivd_strat_def_rate if period==20&treatment==2,  bin(10) percent addlabel title(SE no enforcer) ylabel(0(10) 60)  scheme(s2mono) graphregion(fcolor(white)lcolor(white)) xtitle("")
graph export "$graphixpath\MS23-050_Figure1_right.eps", replace


//Figure 2: Punishmentent Rate and Punishment Intensity under Partial Information

clear
use "$datapath\MS23-050_data_for_analysis.dta" 

// Panel A: Punishment rate
keep if period==20&observer==1&(treatment==3|treatment==4)
gen rate_punishment_def_cat=ceil(rate_punishment_def*10)/10-0.05
recode rate_punishment_def_cat (-.05=.05)
gen freq=1
collapse (sum) freq, by(treatment rate_punishment_def_cat)
drop if rate_punishment_def_cat==.
bysort treatment: egen n_treat=total(freq)
gen frac=freq/n_treat*100
reshape wide freq frac n_treat, i(rate_punishment_def_cat) j(treatment)
tw bar frac3 rate_punishment_def_cat, barwidth(0.1) ytitle(Relative Frequency (in %)) xtitle("") ylabel(0(10)60, angle(0)) xlabel(0(0.1)1, format(%9.1f)) title(WE partial info) ///
graphregion(fcolor(white)lcolor(white)) scheme(s2mono)  ///
|| scatter frac3 rate_punishment_def_cat, ms(i) mlab(frac3) mlabpos(12) mlabcolor(black) legend(off)
graph export "$graphixpath\MS23-050_Figure2_PanelA_left.eps", replace
tw bar frac4 rate_punishment_def_cat, barwidth(0.1) ytitle(Relative Frequency (in %)) xtitle("") ylabel(0(10)60, angle(0)) xlabel(0(0.1)1, format(%9.1f)) title(SE partial info) ///
graphregion(fcolor(white)lcolor(white)) scheme(s2mono)  ///
|| scatter frac4 rate_punishment_def_cat, ms(i) mlab(frac4) mlabpos(12) mlabcolor(black) legend(off)
graph export "$graphixpath\MS23-050_Figure2_PanelA_right.eps", replace



//Panel B: Punishment intensity
clear
use "$datapath\MS23-050_data_for_analysis.dta" 

keep if period==20&observer==1&(treatment==3|treatment==4)
gen punish_default_intens_cat=ceil(punish_default_intens/25)*25-12.5
replace punish_default_intens_cat=212.5 if punish_default_intens_cat>212.5&punish_default_intens_cat!=.
gen freq=1
collapse (sum) freq, by(treatment punish_default_intens_cat)
drop if punish_default_intens_cat==.
bysort treatment: egen n_treat=total(freq)
gen frac=freq/n_treat*100
reshape wide freq frac n_treat, i(punish_default_intens_cat) j(treatment)
gen frac3_round=round(frac3,0.1)
gen frac4_round=round(frac4,0.1)
tw bar frac3 punish_default_intens_cat, barwidth(25) ytitle(Relative Frequency (in %)) xtitle("") ylabel(0(10)60, angle(0)) ///
xlabel(0(50)200 200 ">200") title(WE partial info) ///
graphregion(fcolor(white)lcolor(white)) scheme(s2mono) ///
|| scatter frac3 punish_default_intens_cat, ms(i) mlab(frac3_round) mlabpos(12) mlabcolor(black) legend(off)
graph export "$graphixpath\MS23-050_Figure2_PanelB_left.eps", replace
tw bar frac4 punish_default_intens_cat, barwidth(25) ytitle(Relative Frequency (in %)) xtitle("") ylabel(0(10)60, angle(0)) xlabel(0(50)200 200 ">200") title(SE partial info) ///
graphregion(fcolor(white)lcolor(white)) scheme(s2mono)  ///
|| scatter frac4 punish_default_intens_cat, ms(i) mlab(frac4_round) mlabpos(12) mlabcolor(black) legend(off)
graph export "$graphixpath\MS23-050_Figure2_PanelB_right.eps", replace



//Figure 3: Punishment Rate and Punishment Intensity under Full Information

//Panel A: Punishment Rate
clear
use "$datapath\MS23-050_data_for_analysis.dta"
keep if period==20&observer==1&(treatment==5|treatment==6)
gen rate_punishment_strat_cat=ceil(rate_punishment_strat*10)/10-0.05
recast float rate_punishment_strat_cat
recode rate_punishment_strat_cat (-.05=.05)
gen freq=1
collapse (sum) freq, by(treatment rate_punishment_strat_cat)
drop if rate_punishment_strat_cat==.
bysort treatment: egen n_treat=total(freq)
gen frac=freq/n_treat*100
reshape wide freq frac n_treat, i(rate_punishment_strat_cat) j(treatment)
gen frac5_round=round(frac5,0.1)
gen frac6_round=round(frac6,0.1)
tw bar frac5 rate_punishment_strat_cat, barwidth(0.1) ytitle(Relative Frequency (in %)) xtitle("") ylabel(0(10)60, angle(0)) xlabel(0(0.1)1, format(%9.1f)) title(WE full info) ///
graphregion(fcolor(white)lcolor(white)) scheme(s2mono)  ///
|| scatter frac5 rate_punishment_strat_cat, ms(i) mlab(frac5_round) mlabpos(12) mlabcolor(black) legend(off)
graph export "$graphixpath\MS23-050_Figure3_PanelA_left.eps", replace
tw bar frac6 rate_punishment_strat_cat, barwidth(0.1) ytitle(Relative Frequency (in %)) xtitle("") ylabel(0(10)60, angle(0)) xlabel(0(0.1)1, format(%9.1f)) title(SE full info) ///
graphregion(fcolor(white)lcolor(white)) scheme(s2mono)  ///
|| scatter frac6 rate_punishment_strat_cat, ms(i) mlab(frac6_round) mlabpos(12) mlabcolor(black) legend(off)
graph export "$graphixpath\MS23-050_Figure3_PanelA_right.eps", replace

//Panel B: Punishment Intensity
clear
use "$datapath\MS23-050_data_for_analysis.dta"
keep if period==20&observer==1&(treatment==5|treatment==6)
gen punish_strat_intens_cat=ceil(punish_strat_intens/25)*25-12.5
replace punish_strat_intens_cat=212.5 if punish_strat_intens_cat>212.5&punish_strat_intens_cat!=.
gen freq=1
collapse (sum) freq, by(treatment punish_strat_intens_cat)
drop if punish_strat_intens_cat==.
bysort treatment: egen n_treat=total(freq)
gen frac=freq/n_treat*100
reshape wide freq frac n_treat, i(punish_strat_intens_cat) j(treatment)
gen frac5_round=round(frac5,0.1)
gen frac6_round=round(frac6,0.1)
tw bar frac5 punish_strat_intens_cat, barwidth(25) ytitle(Relative Frequency (in %)) xtitle("") ylabel(0(10)60, angle(0)) xlabel(0(50)200 200 ">200") title(WE full info) ///
graphregion(fcolor(white)lcolor(white)) scheme(s2mono)  ///
|| scatter frac5 punish_strat_intens_cat, ms(i) mlab(frac5_round) mlabpos(12) mlabcolor(black) legend(off)
graph export "$graphixpath\MS23-050_Figure3_PanelB_left.eps", replace
tw bar frac6 punish_strat_intens_cat, barwidth(25) ytitle(Relative Frequency (in %)) xtitle("") ylabel(0(10)60, angle(0)) xlabel(0(50)200 200 ">200") title(SE full info) ///
graphregion(fcolor(white)lcolor(white)) scheme(s2mono) ///
|| scatter frac6 punish_strat_intens_cat, ms(i) mlab(frac6_round) mlabpos(12) mlabcolor(black) legend(off)
graph export "$graphixpath\MS23-050_Figure3_PanelB_right.eps", replace


//APPENDIX FIGURES

//Appendix A: Proofs

//Figure Appendix A1: Graphical Representation of Equilibrium Condition in Proposition 1

clear

use "$datapath\MS23-050_no_enforcer_theory_figure.dta"
//this dataset was created to illustrate the theoretical predictions in proposition 1


//top-left-hand

tw line omega uni_high uni_low k, legend(label(1 "{&Omega}") ///
label(2 "k(1+{&gamma}{sub:SE}{&lambda}(1-F(k)))") label(3 "k(1+{&gamma}{sub:WE}{&lambda}(1-F(k)))") col(3)pos(3)ring(0)) ///
scheme(s2mono) graphregion(fcolor(white)lcolor(white)) xtitle(k) xlabel(0(25)150, format(%9.0f)) ylabel(0(20)140, angle(0)) title(A: Uniform distribution)
graph save "$graphixpath\g1", replace
graph export "$graphixpath\MS23-050_FigureApp_A1_top_left_hand.eps", replace

//top-right-hand


tw line omega norm_high norm_low k, legend(label(1 "{&Omega}") ///
label(2 "k(1+{&gamma}{sub:SE}{&lambda}(1-F(k)))") label(3 "k(1+{&gamma}{sub:WE}{&lambda}(1-F(k)))") col(3)pos(3)ring(0)) ///
scheme(s2mono) graphregion(fcolor(white)lcolor(white)) xtitle(k) xlabel(0(25)150, format(%9.0f)) ylabel(0(20)140, angle(0)) title(B: Normal distribution)
graph save "$graphixpath\g2", replace
graph export "$graphixpath\MS23-050_FigureApp_A1_top_right_hand.eps", replace

//bottom-left-hand


tw line omega tri_high tri_low k, legend(label(1 "{&Omega}") ///
label(2 "k(1+{&gamma}{sub:SE}{&lambda}(1-F(k)))") label(3 "k(1+{&gamma}{sub:WE}{&lambda}(1-F(k)))") col(3)pos(3)ring(0)) ///
scheme(s2mono) graphregion(fcolor(white)lcolor(white)) xtitle(k) xlabel(0(25)150, format(%9.0f)) ylabel(0(20)140, angle(0)) title(C: Triangle distribution)
graph save "$graphixpath\g3", replace
graph export "$graphixpath\MS23-050_FigureApp_A1_bottom_left_hand.eps", replace


//bottom-right-hand


tw line omega narrow_high narrow_low k, legend(label(1 "{&Omega}") ///
label(2 "k(1+{&gamma}{sub:SE}{&lambda}(1-F(k)))") label(3 "k(1+{&gamma}{sub:WE}{&lambda}(1-F(k)))") col(3)pos(3)ring(0)) ///
scheme(s2mono) graphregion(fcolor(white)lcolor(white)) xtitle(k) xlabel(0(25)150, format(%9.0f)) ylabel(0(20)140, angle(0)) title(D: Normal distribution)
graph save "$graphixpath\g4", replace
graph export "$graphixpath\MS23-050_FigureApp_A1_bottom_right_hand.eps", replace

//Figure Appendix A1: complete

cd "$graphixpath"
grc1leg g1.gph g2.gph g3.gph g4.gph, row(2) iscale(0.7) graphregion(fcolor(white)lcolor(white))
graph export "$graphixpath\MS23-050_FigureApp_A1_all.eps", replace

//Figure Appendix A2: Representation of Equilibrium Conditions in Propositions 1 and 3

clear

use "$datapath\MS23-050_enforcer_theory_figure.dta"
//this dataset was created to illustrate the theoretical predictions in proposition 1 and 3

tw line left_high left_low omega partialben pben_low fullben fullbenlow k, ///
legend(label(1 "k(1+{&gamma}{sub:SE}{&lambda}(1-F(k)))") label(2 "k(1+{&gamma}{sub:SE}{&lambda}(1-F(k)))") label(3 "No enforcers: {&Omega}") ///
label(4 "SE Partial Info: {&Omega}-{&rho}(b)P") label(5 "WE Partial Info: {&Omega}-{&rho}(b)P") label(6 "SE Full Info: {&Omega}-{&rho}(1)P") ///
label(7 "WE Full Info: {&Omega}-{&rho}(1)P") ///
col(2) hole(4) pos(6) symxsize(*0.55)) scheme(s2mono) graphregion(fcolor(white)lcolor(white)) xtitle(k) xlabel(0(25)150, format(%9.0f)) ylabel(0(20)140, angle(0))
graph export "$graphixpath\MS23-050_FigureApp_A2.eps", replace


// Appendix D: Treatment outcomes over time


clear
use "$datapath\MS23-050_data_for_analysis.dta"



//Figure Appendix D1


graph bar (mean) strat_default_we_p5  strat_default_se_p5, over(period_5, label(angle(forty_five))) over(condition, relabel(1 "No enforcer" 2 "Enforcer partial info" 3 "Enforcer full info")  label(angle(horizontal)) ) ytitle(" ") ylabel(, labels) ymtick(, nolabels) legend(order(1 "WE" 2 "SE")) scheme(s2mono) graphregion(fcolor(white)lcolor(white))
graph export "$graphixpath\MS23-050_FigureApp_D1.eps", replace


//Figure Appendix D2

graph bar (mean) tot_pun_default_we tot_pun_default_se if treatment==3|treatment==4,  over(period_5, label(angle(forty_five))) ytitle(" ") ylabel(, labels) ymtick(, nolabels)  legend(order(1 "WE partial info" 2 "SE partial info")) scheme(s2mono) graphregion(fcolor(white)lcolor(white))
graph export "$graphixpath\MS23-050_FigureApp_D2.eps", replace

//Figure Appendix D3

graph bar (mean) tot_pun_strat_we tot_pun_strat_se if treatment==5|treatment==6, over(period_5, label(angle(forty_five))) ytitle(" ") ylabel(, labels) ymtick(, nolabels)  legend(order(1 "WE full info" 2 "SE full info")) scheme(s2mono) graphregion(fcolor(white)lcolor(white))
graph export "$graphixpath\MS23-050_FigureApp_D3.eps", replace

// Appendix E: Social norm enforcement and and strategic default rates

//Figure Appenidx E1

//left-hand figure

histogram indivd_strat_def_rate if period==20&treatment==3, bin(10) percent addlabel title(WE partial info) ylabel(0(10)60) xtitle( " ") scheme(s2mono) graphregion(fcolor(white)lcolor(white))
graph export "$graphixpath\MS23-050_FigureApp_E1_left.eps", replace

//right-hand figure

histogram indivd_strat_def_rate if period==20&treatment==4,  bin(10) percent addlabel title(SE partial info) ylabel(0(10)60) xtitle( " ") scheme(s2mono) graphregion(fcolor(white)lcolor(white))
graph export "$graphixpath\MS23-050_FigureApp_E1_right.eps", replace

//Figure Appenidx E2

//left-hand figure

histogram indivd_strat_def_rate if period==20&treatment==5,  bin(10) percent addlabel title(WE full info) ylabel(0(10)60) xtitle( " ") scheme(s2mono) graphregion(fcolor(white)lcolor(white))
graph export "$graphixpath\MS23-050_FigureApp_E2_left.eps", replace

//right-hand figure

histogram indivd_strat_def_rate if period==20&treatment==6,  bin(10) percent addlabel title(SE full info) ylabel(0(10)60) xtitle( " ") scheme(s2mono) graphregion(fcolor(white)lcolor(white))
graph export "$graphixpath\MS23-050_FigureApp_E2_right.eps", replace

**********************************
*ANALYSIS
**********************************



use "$datapath\MS23-050_analyzeable_experimental_data.dta" 
  
//Table 4: Summary Statistics by Treatment

//Table contains sum-stats from different treatments and tests based on matching group averages
// Table was manually put together based on the following statistics: 

*Variable: Strategig defaults: line 1: mean; line 2 (in parentheses): N; line 3: p-values from one-sided ranksum tests at the matching-group level
estpost tabstat strat_default  , by(treatment) s(mean N) 
*Ranksum tests on the matching-group level
preserve
collapse (mean) strat_default treatment, by(mg_session)
ranksum strat_default if treatment==1|treatment==2, by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.06
ranksum strat_default if treatment==3|treatment==4, by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.23
ranksum strat_default if treatment==5|treatment==6, by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.30
restore

*Variable: Punishment if default: line 1: mean; line 2 (in parentheses): N; line 3: p-values from one-sided ranksum tests at the matching-group level
estpost tabstat   punish_received  if default==1&(treatment==3|treatment==4), by(treatment) s(mean N) 
preserve
collapse (mean) punish_received treatment, by(mg_session default)
ranksum punish_received if default==1&(treatment==3|treatment==4), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.04
restore

*Variable: Punishment if forced default: line 1: mean; line 2 (in parentheses): N; line 3: p-values from one-sided ranksum tests at the matching-group level
estpost tabstat   punish_received  if success==0&(treatment==5|treatment==6), by(treatment) s(mean N) 
preserve
collapse (mean) punish_received treatment, by(mg_session success)
ranksum punish_received if success==0&(treatment==5|treatment==6), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.22
restore

*Variable: Punishment if strategic default: line 1: mean; line 2 (in parentheses): N; line 3: p-values from one-sided ranksum tests at the matching-group level
estpost tabstat   punish_received if strat_default==1&(treatment==5|treatment==6), by(treatment) s(mean N) 
preserve
collapse (mean) punish_received   treatment, by(mg_session strat_default)
ranksum punish_received if strat_default==1&(treatment==5|treatment==6), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.48
restore

*Variable: Punishment if repay: line 1: mean; line 2 (in parentheses): N; line 3: p-values from one-sided ranksum tests at the matching-group level
estpost tabstat   punish_received  if cooperate==1&treatment>2, by(treatment) s(mean N) 
preserve
collapse (mean) punish_received treatment, by(mg_session cooperate)
ranksum punish_received if cooperate==1&(treatment==3|treatment==4), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.19
ranksum punish_received if cooperate==1&(treatment==5|treatment==6), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.27
restore

// Appendix B: Regression results

//Table B1: inear regressions: Strategic default (Panel A) and punishment points assigned (Panel B) – All periods

//Panel A and Panel B manually merged to Table B1
// Regressions for Panel A and Panel B below

//Panel A: Strategic default

 
reg strat_default  we i.period if treatment==1|treatment==2, cluster(mg_session)
  
estimates store sd_noenforcer
 
reg strat_default  we i.period if treatment==3|treatment==4, cluster(mg_session)
  
estimates store sd_enforcer_partial
  
reg strat_default  we i.period if treatment==5|treatment==6, cluster(mg_session)
  
estimates store sd_enforcer_full
 
reg strat_default  partial full  i.period if we==1, cluster(mg_session)
 
estimates store sd_withinwe

reg strat_default  partial full  i.period if we==0, cluster(mg_session)
 
estimates store sd_withinse


esttab sd_noenforcer sd_enforcer_partial sd_enforcer_full sd_withinwe sd_withinse   using "$tablepath\MS23-050_TableB1_PanelA.tex" , addnotes("Note: Cluster Robust Standard Errors in parentheses.  * \(p<0.1\), ** \(p<0.05\), *** \(p<0.01\)} ") label title("Linear regressions: Strategic default (Panel A) and punishment points assigned (Panel B) – All periods \label{tab: OLS}") replace nonotes tex se scalars(N r2 PeriodFE Cluster) star(* 0.1 ** 0.05 *** 0.01)  keep(we partial full)
//cluster 20 in reg 1-3 and 30 in reg 4 and 5 // period Fe = Yes in all regressions

estimates clear

//Panel B: Punishment


 reg punish_assigned_default_strat  we i.period if observer==1&(treatment==3|treatment==4), cluster(mg_session)
 
 est store punish_partial
 
reg punish_assigned_default_strat  we i.period if observer==1&(treatment==5|treatment==6), cluster(mg_session)
 
est store punish_full
  
reg punish_assigned_default_strat  full i.period if observer==1&(treatment==3|treatment==5), cluster(mg_session)
  
est store punish_we
 
reg punish_assigned_default_strat  full i.period if observer==1&(treatment==4|treatment==6), cluster(mg_session)
 
est store punish_se
 
 
esttab  punish_partial punish_full  punish_we punish_se  using "$tablepath\MS23-050_TableB1_PanelB.tex" , addnotes("Note: Cluster Robust Standard Errors in parentheses.  * \(p<0.1\), ** \(p<0.05\), *** \(p<0.01\)} ") label title("Linear regressions: Strategic default (Panel A) and punishment points assigned (Panel B) – All periods \label{tab: OLS}") replace nonotes tex se scalars(N r2 PeriodFE Cluster) star(* 0.1 ** 0.05 *** 0.01)  keep(we full)
//cluster 20 in all regressions // period Fe = Yes in all regressions //note: first column in Panel B empty as in Panel A no enforcer conditions are compared with each other (without punishment)
 
 estimates clear
 
 
// Appendix C: Period one results

//Table C1: Summary Statistics by Treatment for Period one

//Table contains sum-stats from different treatments and tests based on matching group averages
// Table was manually put together based on the following statistics: 

*Variable: Strategig default rate: line 1: mean; line 2 (in parentheses): N; line 3: p-values from one-sided ranksum tests at the individual level in period 1
estpost tabstat strat_default  if period==1, by(treatment) s(mean N) 
*Ranksum tests at the individual level in period 1
ranksum strat_default if period==1&(treatment==1|treatment==2), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.02
ranksum strat_default if period==1&(treatment==3|treatment==4), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.23
ranksum strat_default if period==1&(treatment==5|treatment==6), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.16

*Variable: Punishment if default: line 1: mean; line 2 (in parentheses): N; line 3: p-values from one-sided ranksum tests at the individual level in period 1
estpost tabstat   punish_received  if period==1&default==1&(treatment==3|treatment==4), by(treatment) s(mean N) 
*Ranksum tests at the individual level in period 1
ranksum punish_received if period==1&default==1&(treatment==3|treatment==4), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.04

*Variable: Punishment if forced default: line 1: mean; line 2 (in parentheses): N; line 3: p-values from one-sided ranksum tests at the individual level in period 1
estpost tabstat   punish_received  if period==1&success==0&(treatment==5|treatment==6), by(treatment) s(mean N) 
*Ranksum tests at the individual level in period 1
ranksum punish_received if period==1&success==0&(treatment==5|treatment==6), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.46


*Variable: Punishment if strategic default: line 1: mean; line 2 (in parentheses): N; line 3: p-values from one-sided ranksum tests at the individual level in period 1
estpost tabstat   punish_received if period==1&strat_default==1&(treatment==5|treatment==6), by(treatment) s(mean N) 
*Ranksum tests at the individual level in period 1
ranksum punish_received if period==1&strat_default==1&(treatment==5|treatment==6), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.23


*Variable: Punishment if repay: line 1: mean; line 2 (in parentheses): N; line 3: p-values from one-sided ranksum tests at the individual level in period 1
estpost tabstat   punish_received  if period==1&cooperate==1&treatment>2, by(treatment) s(mean N) 
*Ranksum tests at the individual level in period 1
ranksum punish_received if period==1&cooperate==1&(treatment==3|treatment==4), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.11
ranksum punish_received if period==1&cooperate==1&(treatment==5|treatment==6), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.03

//Table C2: Linear regressions: Strategic default (Panel A) and punishment points assigned (Panel B) – Period One


//Panel A and Panel B manually merged to Table C2
// Regressions for Panel A and Panel B below

//Panel A: Strategic default

 
reg strat_default  we  if period==1&(treatment==1|treatment==2), cluster(mg_session)
  
estimates store sd_noenforcer
 
reg strat_default  we if period==1&(treatment==3|treatment==4), cluster(mg_session)
  
estimates store sd_enforcer_partial
  
reg strat_default  we  if period==1&(treatment==5|treatment==6), cluster(mg_session)
  
estimates store sd_enforcer_full
 
reg strat_default  partial full   if period==1&we==1, cluster(mg_session)
 
estimates store sd_withinwe

reg strat_default  partial full  if period==1&we==0, cluster(mg_session)
 
estimates store sd_withinse


esttab sd_noenforcer sd_enforcer_partial sd_enforcer_full sd_withinwe sd_withinse   using "$tablepath\MS23-050_TableC2_PanelA.tex" , addnotes("Note: Cluster Robust Standard Errors in parentheses.  * \(p<0.1\), ** \(p<0.05\), *** \(p<0.01\)} ") label title("Linear regressions: Strategic default (Panel A) and punishment points assigned (Panel B) – All periods \label{tab: OLS}") replace nonotes tex se scalars(N r2 PeriodFE Cluster) star(* 0.1 ** 0.05 *** 0.01)  keep(we partial full)
//cluster 20 in reg 1-3 and 30 in reg 4 and 5 // period Fe = Yes in all regressions

estimates clear


//Panel B: Punishment

*create a variable that allows comparing punishment of defaults in partial info with punishment of strategic default in full info conditions


 reg punish_assigned_default_strat  we if period==1&observer==1&(treatment==3|treatment==4), cluster(mg_session)
 
 est store punish_partial
 
reg punish_assigned_default_strat  we  if period==1&observer==1&(treatment==5|treatment==6), cluster(mg_session)
 
est store punish_full
  
reg punish_assigned_default_strat  full if period==1&observer==1&(treatment==3|treatment==5), cluster(mg_session)
  
est store punish_we
 
reg punish_assigned_default_strat  full  if period==1&observer==1&(treatment==4|treatment==6), cluster(mg_session)
 
est store punish_se
 
 
esttab  punish_partial punish_full  punish_we punish_se  using "$tablepath\MS23-050_TableC2_PanelB.tex" , addnotes("Note: Cluster Robust Standard Errors in parentheses.  * \(p<0.1\), ** \(p<0.05\), *** \(p<0.01\)} ") label title("Linear regressions: Strategic default (Panel A) and punishment points assigned (Panel B) – All periods \label{tab: OLS}") replace nonotes tex se scalars(N r2 PeriodFE Cluster) star(* 0.1 ** 0.05 *** 0.01)  keep(we full)
//cluster 20 in all regressions // period Fe = Yes in all regressions //note: first column in Panel B empty as in Panel A no enforcer conditions are compared with each other (without punishment)
 
 estimates clear



//Tests not in summary statistics or regressions tables


*Period 5 intervals
*ranksum tests // p values: one-sided

*no enforcers // Footnote 22
preserve
collapse (mean) strat_default treatment, by(mg_session period_5)
ranksum strat_default if period_5==1&(treatment==1|treatment==2), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.04
ranksum strat_default if period_5==2&(treatment==1|treatment==2), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.12
ranksum strat_default if period_5==3&(treatment==1|treatment==2), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.07
ranksum strat_default if period_5==4&(treatment==1|treatment==2), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.34
restore

*partial info // Footnote 26
preserve
collapse (mean) strat_default treatment, by(mg_session period_5)
ranksum strat_default if period_5==1&(treatment==3|treatment==4), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.15
ranksum strat_default if period_5==2&(treatment==3|treatment==4), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.14
ranksum strat_default if period_5==3&(treatment==3|treatment==4), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.41
ranksum strat_default if period_5==4&(treatment==3|treatment==4), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.38
restore

*full info // Footnote 30
preserve
collapse (mean) strat_default treatment, by(mg_session period_5)
ranksum strat_default if period_5==1&(treatment==5|treatment==6), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.48
ranksum strat_default if period_5==2&(treatment==5|treatment==6), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.5
ranksum strat_default if period_5==3&(treatment==5|treatment==6), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.38
ranksum strat_default if period_5==4&(treatment==5|treatment==6), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.47
restore

//Kolmogorov smirnoff test on individual strategic default rate // Section 4.1


ksmirnov indivd_strat_def_rate if period==20&treatment==1|period==20&treatment==2, by(treatment) 
*p=0.01

//Kolmogorov smirnoff test on punishment

*partial info // Section 4.2.1
*rate
ksmirnov   rate_punishment_def if treatment==3&observer==1&period==20|treatment==4&observer==1&period==20, by (treatment)
*p=0.57

*intensity
ksmirnov   punish_default_intens if treatment==3&observer==1&period==20|treatment==4&observer==1&period==20, by (treatment)
*p=0.57

*full info // Section 4.2.2
*rate
ksmirnov   rate_punishment_strat if treatment==5&observer==1&period==20|treatment==6&observer==1&period==20, by (treatment)
*p=0.98

*intensity
ksmirnov   punish_strat_intens if treatment==5&observer==1&period==20|treatment==6&observer==1&period==20, by (treatment)
*p=0.99

//ranksum test punishment assigned within 5 period intervals

*partial info // Footnote 25
preserve
collapse (mean) punish_assigned_default treatment, by(mg_session period_5)
ranksum punish_assigned_default if period_5==1&(treatment==3|treatment==4), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.01
ranksum punish_assigned_default if period_5==2&(treatment==3|treatment==4), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.05
ranksum punish_assigned_default if period_5==3&(treatment==3|treatment==4), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.20
ranksum punish_assigned_default if period_5==4&(treatment==3|treatment==4), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.07
restore


*full info // Footnote 30
preserve
collapse (mean) punish_assigned_strategic treatment, by(mg_session period_5)
ranksum punish_assigned_strategic if period_5==1&(treatment==5|treatment==6), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.09
ranksum punish_assigned_strategic if period_5==2&(treatment==5|treatment==6), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.41
ranksum punish_assigned_strategic if period_5==3&(treatment==5|treatment==6), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.34
ranksum punish_assigned_strategic if period_5==4&(treatment==5|treatment==6), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.38
restore


//ranksum test strategic default within we // Section 4.2.3
preserve
collapse (mean) strat_default treatment, by(mg_session)
ranksum strat_default if treatment==1|treatment==3, by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.09
ranksum strat_default if treatment==3|treatment==5, by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.09
ranksum strat_default if treatment==1|treatment==5, by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.01
restore


//ranksum test strategic default within we period 1 // Section 4.2.3

ranksum strat_default if period==1&(treatment==1|treatment==3), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.1
ranksum strat_default if period==1&(treatment==3|treatment==5), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.04
ranksum strat_default if period==1&(treatment==1|treatment==5), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: <0.01

//ranksum test strategic default within se // Section 4.2.3

preserve // Section 4.2.3
collapse (mean) strat_default treatment, by(mg_session)
ranksum strat_default if treatment==2|treatment==4, by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.46
ranksum strat_default if treatment==4|treatment==6, by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.28
ranksum strat_default if treatment==2|treatment==6, by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.36
restore


//ranksum test strategic default within se period 1 // Footnote 32

ranksum strat_default if period==1&(treatment==2|treatment==4), by(treatment)  // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.49
ranksum strat_default if period==1&(treatment==4|treatment==6), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.34
ranksum strat_default if period==1&(treatment==2|treatment==6), by(treatment) // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.34



//individual FE regressions

*Strategic default // Footnote 21

reg strat_default period_5 i.id if treatment==1&observer==0,  cluster(mg_session) 
 *N=1450; \beta=0.12; p<0.01$

reg strat_default period_5 i.id if treatment==2&observer==0,  cluster(mg_session) 
*N=824; \beta=0.07; p=0.015$

*punishment 

*partial info // Footnote 25
reg punish_assigned_default period_5 i.id if treatment==3&observer==1,  cluster(mg_session) 
*N=761; \beta=7.66; p=0.04


reg punish_assigned_default period_5 i.id if treatment==4&observer==1,  cluster(mg_session) 
*N=639; \beta=6.89; p=0.06

*full info // Footnote 30
reg punish_assigned_strategic period_5 i.id if treatment==5&observer==1,  cluster(mg_session) 
*N=319;\beta=5.52; p=0.26


reg punish_assigned_strategic period_5 i.id if treatment==6&observer==1,  cluster(mg_session) 
*N=517;\beta=-2.34; p=0.72


//siganrank tests for punishment behavior of different types of defaults within we and se


*Partial info //Footnote 23 and Footnote 24 
* all periods
preserve
collapse (mean) punish_assigned_default punish_assigned_coop punish_assigned_fund  treatment, by(mg_session)
*we
signrank punish_assigned_default=punish_assigned_coop if treatment ==3 // two sided test: we report one-sided p-values in paper; p-value one-sided: <0.01
*se
signrank punish_assigned_default=punish_assigned_coop if treatment ==4 // two sided test: we report one-sided p-values in paper; p-value one-sided: <0.01
restore
*period 1
*we
signrank punish_assigned_default=punish_assigned_coop if treatment ==3&period==1 // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.02
*se
signrank punish_assigned_default=punish_assigned_coop if treatment ==4&period==1 // two sided test: we report one-sided p-values in paper; p-value one-sided: 0.03


*full info //Footnote 27
*all periods
preserve
collapse (mean) punish_assigned_default punish_assigned_coop punish_assigned_fund  treatment, by(mg_session)
*we
signrank punish_assigned_default=punish_assigned_coop if treatment ==5 // two sided test: we report one-sided p-values in paper; p-value one-sided: <0.01
signrank punish_assigned_default=punish_assigned_fund if treatment ==5 // two sided test: we report one-sided p-values in paper; p-value one-sided: <0.01
*se
signrank punish_assigned_default=punish_assigned_coop if treatment ==6 // two sided test: we report one-sided p-values in paper; p-value one-sided: <0.01
signrank punish_assigned_default=punish_assigned_fund if treatment ==6 // two sided test: we report one-sided p-values in paper; p-value one-sided: <0.01
restore












